@@ -1,3 +1,3 @@
+from .layers import layer
 from .models import deepfm
-from .models import fm
-from .layers import layper
\ No newline at end of file
+from .models import fm
\ No newline at end of file
